@@ -4,8 +4,8 @@
 // Author:      Mattia Barbon
 // Modified by:
 // Created:     29/10/2000
-// RCS-ID:      $Id: controls.cpp,v 1.38 2006/12/03 14:56:38 mbarbon Exp $
-// Copyright:   (c) 2000-2006 Mattia Barbon
+// RCS-ID:      $Id: controls.cpp,v 1.41 2007/04/11 17:20:09 mbarbon Exp $
+// Copyright:   (c) 2000-2007 Mattia Barbon
 // Licence:     This program is free software; you can redistribute it and/or
 //              modify it under the same terms as Perl itself
 /////////////////////////////////////////////////////////////////////////////
@@ -241,12 +241,18 @@ double treectrl_constant( const char* name, int arg )
       r( wxEVT_COMMAND_TREE_ITEM_RIGHT_CLICK );
       r( wxEVT_COMMAND_TREE_ITEM_MIDDLE_CLICK );
       r( wxEVT_COMMAND_TREE_END_DRAG );
+#if defined(__WXMSW__)
+      r( wxEVT_COMMAND_TREE_STATE_IMAGE_CLICK );
+      r( wxEVT_COMMAND_TREE_ITEM_GETTOOLTIP );
+#endif
 
       break;
   case 'T':
     r( wxTR_DEFAULT_STYLE );            // treectrl
     r( wxTR_EDIT_LABELS );              // treectrl
+#if WXPERL_W_VERSION_LT( 2, 9, 0 ) || WXWIN_COMPATIBILITY_2_8
     r( wxTR_EXTENDED );                 // treectrl
+#endif
     r( wxTR_FULL_ROW_HIGHLIGHT );       // treectrl
     r( wxTR_HAS_BUTTONS );              // treectrl
     r( wxTR_HAS_VARIABLE_ROW_HEIGHT );  // treectrl
