@@ -4,8 +4,8 @@
 ## Author:      Mattia Barbon
 ## Modified by:
 ## Created:     23/05/2002
-## RCS-ID:      $Id: STC.pm,v 1.4 2004/12/21 21:12:57 mbarbon Exp $
-## Copyright:   (c) 2002-2004 Mattia Barbon
+## RCS-ID:      $Id: STC.pm,v 1.5 2005/01/09 22:36:42 mbarbon Exp $
+## Copyright:   (c) 2002-2005 Mattia Barbon
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
 #############################################################################
@@ -29,7 +29,7 @@ Wx::wx_boot( 'Wx::STC', $VERSION );
 no strict;
 
 package Wx::StyledTextCtrl;   @ISA = qw(Wx::Control);
-package Wx::StyledTextEvent;  @ISA = qw(WX::CommandEvent);
+package Wx::StyledTextEvent;  @ISA = qw(Wx::CommandEvent);
 
 package Wx::Event;
 
