@@ -4,8 +4,8 @@
 ## Author:      Mattia Barbon
 ## Modified by:
 ## Created:     25/11/2000
-## RCS-ID:      $Id: App.pm,v 1.14 2004/10/19 20:28:11 mbarbon Exp $
-## Copyright:   (c) 2000-2003 Mattia Barbon
+## RCS-ID:      $Id: App.pm,v 1.17 2006/08/05 13:18:45 mbarbon Exp $
+## Copyright:   (c) 2000-2003, 2006 Mattia Barbon
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
 #############################################################################
@@ -31,19 +31,21 @@ sub new {
     $Wx::wxTheApp = $this;
   }
 
-  $this->SetAppName($_[0]); # reasonable default for Wx::ConfigBase::Get
+  $this->SetAppName( $_[0] ); # reasonable default for Wx::ConfigBase::Get
 
-  my $ret = Wx::_App::Start($this,$this->can('OnInit'));
-  Wx::_croak( 'OnInit must return a true return value' )
-    # why does OnInit always return 0 on Mac?
-    unless $Wx::_platform == 4 || $ret;
+  my $ret = Wx::_App::Start( $this, $_[1] || $this->can( 'OnInit' ) );
+  Wx::_croak( 'OnInit must return a true return value' ) unless $ret;
 
   $this;
 }
 
-sub OnInit {
-  0;
-}
+sub OnInit { 0 }
+
+package Wx::SimpleApp;
+
+@Wx::SimpleApp::ISA = qw(Wx::App);
+
+sub OnInit { 1 }
 
 1;
 
